@@ -64,12 +64,13 @@ if (adminer()->homepage()) {
 			echo "<form action='' method='post'>\n";
 			if (support("table")) {
 				echo "<fieldset><legend>" . lang('Search data in tables') . " <span id='selected2'></span></legend><div>";
-				echo "<input type='search' name='query' value='" . h($_POST["query"]) . "'>";
+				echo html_select("op", adminer()->operators(), idx($_POST, "op", JUSH == "elastic" ? "should" : "LIKE %%"));
+				echo " <input type='search' name='query' value='" . h($_POST["query"]) . "'>";
 				echo script("qsl('input').onkeydown = partialArg(bodyKeydown, 'search');", "");
 				echo " <input type='submit' name='search' value='" . lang('Search') . "'>\n";
 				echo "</div></fieldset>\n";
 				if ($_POST["search"] && $_POST["query"] != "") {
-					$_GET["where"][0]["op"] = driver()->convertOperator("LIKE %%");
+					$_GET["where"][0]["op"] = $_POST["op"];
 					search_tables();
 				}
 			}
@@ -95,8 +96,9 @@ if (adminer()->homepage()) {
 				$id = h("Table-" . $name);
 				echo '<tr><td>' . checkbox(($view ? "views[]" : "tables[]"), $name, in_array("$name", $tables_views, true), "", "", "", $id); // "$name" to check numeric table names
 				echo '<th>' . (support("table") || support("indexes") ? "<a href='" . h(ME) . "table=" . urlencode($name) . "' title='" . lang('Show structure') . "' id='$id'>" . h($name) . '</a>' : h($name));
-				if ($view) {
-					echo '<td colspan="6"><a href="' . h(ME) . "view=" . urlencode($name) . '" title="' . lang('Alter view') . '">' . (preg_match('~materialized~i', $type) ? lang('Materialized view') : lang('View')) . '</a>';
+				if ($view && !preg_match('~materialized~i', $type)) {
+					$title = lang('View');
+					echo '<td colspan="6">' . (support("view") ? "<a href='" . h(ME) . "view=" . urlencode($name) . "' title='" . lang('Alter view') . "'>$title</a>" : $title);
 					echo '<td align="right"><a href="' . h(ME) . "select=" . urlencode($name) . '" title="' . lang('Select data') . '">?</a>';
 				} else {
 					foreach (
@@ -131,6 +133,7 @@ if (adminer()->homepage()) {
 			echo "\n";
 
 			echo "</table>\n";
+			echo script("ajaxSetHtml('" . js_escape(ME) . "script=db');");
 			echo "</div>\n";
 			if (!information_schema(DB)) {
 				echo "<div class='footer'><div>\n";
@@ -147,18 +150,23 @@ if (adminer()->homepage()) {
 				. "<input type='submit' name='truncate' value='" . lang('Truncate') . "'> " . on_help(JUSH == "sqlite" ? "'DELETE'" : "'TRUNCATE" . (JUSH == "pgsql" ? "'" : " TABLE'")) . confirm()
 				. "<input type='submit' name='drop' value='" . lang('Drop') . "'>" . on_help("'DROP TABLE'") . confirm() . "\n";
 				$databases = (support("scheme") ? adminer()->schemas() : adminer()->databases());
+				echo "</div></fieldset>\n";
+				$script = "";
 				if (count($databases) != 1 && JUSH != "sqlite") {
+					echo "<fieldset><legend>" . lang('Move to other database') . " <span id='selected3'></span></legend><div>";
 					$db = (isset($_POST["target"]) ? $_POST["target"] : (support("scheme") ? $_GET["ns"] : DB));
-					echo "<p><label>" . lang('Move to other database') . ": ";
 					echo ($databases ? html_select("target", $databases, $db) : '<input name="target" value="' . h($db) . '" autocapitalize="off">');
 					echo "</label> <input type='submit' name='move' value='" . lang('Move') . "'>";
 					echo (support("copy") ? " <input type='submit' name='copy' value='" . lang('Copy') . "'> " . checkbox("overwrite", 1, $_POST["overwrite"], lang('overwrite')) : "");
-					echo "\n";
+					echo "</div></fieldset>\n";
+					$script = " selectCount('selected3', formChecked(this, /^(tables|views)\[/));";
 				}
 				echo "<input type='hidden' name='all' value=''>"; // used by trCheck()
-				echo script("qsl('input').onclick = function () { selectCount('selected', formChecked(this, /^(tables|views)\[/));" . (support("table") ? " selectCount('selected2', formChecked(this, /^tables\[/) || $tables);" : "") . " }");
+				echo script("qsl('input').onclick = function () { selectCount('selected', formChecked(this, /^(tables|views)\[/));"
+					. (support("table") ? " selectCount('selected2', formChecked(this, /^tables\[/) || $tables);" : "")
+					. "$script }")
+				;
 				echo input_token();
-				echo "</div></fieldset>\n";
 				echo "</div></div>\n";
 			}
 			echo "</form>\n";
@@ -239,9 +247,5 @@ if (adminer()->homepage()) {
 			}
 			echo '<p class="links"><a href="' . h(ME) . 'event=">' . lang('Create event') . "</a>\n";
 		}
-
-		if ($tables_list) {
-			echo script("ajaxSetHtml('" . js_escape(ME) . "script=db');");
-		}
 	}
 }
