@@ -264,9 +264,10 @@ function where(array $where, array $fields = array()): string {
 		$field_type = $field["type"];
 		$return[] = $column
 			. (JUSH == "sql" && $field_type == "json" ? " = CAST(" . q($val) . " AS JSON)"
+				: (JUSH == "pgsql" && preg_match('~^json~', $field_type) ? "::jsonb = " . q($val) . "::jsonb"
 				: (JUSH == "sql" && is_numeric($val) && preg_match('~\.~', $val) ? " LIKE " . q($val) // LIKE because of floats but slow with ints
 				: (JUSH == "mssql" && strpos($field_type, "datetime") === false ? " LIKE " . q(preg_replace('~[_%[]~', '[\0]', $val)) // LIKE because of text but it does not work with datetime
-				: " = " . unconvert_field($field, q($val)))))
+				: " = " . unconvert_field($field, q($val))))))
 		; //! enum and set
 		if (JUSH == "sql" && preg_match('~char|text~', $field_type) && preg_match("~[^ -@]~", $val)) { // not just [a-z] to catch non-ASCII characters
 			$return[] = "$column = " . q($val) . " COLLATE " . charset(connection()) . "_bin";
@@ -291,7 +292,7 @@ function where_check(string $val, array $fields = array()): string {
 * @param int $i condition order
 * @param string $column column identifier
 */
-function where_link(int $i, string $column, string $value, string $operator = "="): string {
+function where_link(int $i, string $column, ?string $value, string $operator = "="): string {
 	return "&where%5B$i%5D%5Bcol%5D=" . urlencode($column) . "&where%5B$i%5D%5Bop%5D=" . urlencode(($value !== null ? $operator : "IS NULL")) . "&where%5B$i%5D%5Bval%5D=" . urlencode($value);
 }
 
@@ -337,11 +338,11 @@ function get_settings(string $cookie): array {
 }
 
 /** Get setting stored in a cookie
+* @param mixed $default
 * @return mixed
 */
-function get_setting(string $key, string $cookie = "adminer_settings") {
-	$settings = get_settings($cookie);
-	return $settings[$key];
+function get_setting(string $key, string $cookie = "adminer_settings", $default = null) {
+	return idx(get_settings($cookie), $key, $default);
 }
 
 /** Store settings to a cookie
@@ -685,7 +686,7 @@ function file_open_lock(string $filename) {
 	if (!$fp) {
 		return;
 	}
-	chmod($filename, 0660);
+	@chmod($filename, 0660); // @ - may not be permitted
 	if (!flock($fp, LOCK_EX)) {
 		fclose($fp);
 		return;
@@ -790,6 +791,13 @@ function select_value($val, string $link, array $field, ?string $text_length): s
 	return adminer()->selectVal($return, $link, $field, $val);
 }
 
+/** Check whether the field type is blob or equivalent
+* @param Field $field
+*/
+function is_blob(array $field): bool {
+	return preg_match('~blob|bytea|raw|file~', $field["type"]) && !in_array($field["type"], idx(driver()->structuredTypes(), lang('User types'), array()));
+}
+
 /** Check whether the string is e-mail address */
 function is_mail(?string $email): bool {
 	$atom = '[-a-z0-9!#$%&\'*+/=?^_`{|}~]'; // characters of local-name
@@ -808,7 +816,17 @@ function is_url(?string $string): bool {
 * @param Field $field
 */
 function is_shortable(array $field): bool {
-	return preg_match('~char|text|json|lob|geometry|point|linestring|polygon|string|bytea~', $field["type"]);
+	return preg_match('~char|text|json|lob|geometry|point|linestring|polygon|string|bytea|hstore~', $field["type"]);
+}
+
+/** Split server into host and (port or socket)
+* @return array{0: string, 1: string}
+*/
+function host_port(string $server) {
+	return (preg_match('~^(\[(.+)]|([^:]+)):([^:]+)$~', $server, $match) // [a:b] - IPv6
+		? array($match[2] . $match[3], $match[4])
+		: array($server, '')
+	);
 }
 
 /** Get query to compute number of found rows
