@@ -93,6 +93,13 @@ function messagesPrint(parent) {
 	for (const el of qsa('.toggle', parent)) {
 		el.onclick = partial(toggle, el.getAttribute('href').substr(1));
 	}
+	for (const el of qsa('.copy', parent)) {
+		el.onclick = () => {
+			navigator.clipboard.writeText(qs('code', el.parentElement).innerText).then(() => el.textContent = '✓');
+			setTimeout(() => el.textContent = '🗐', 1000);
+			return false;
+		};
+	}
 }
 
 
@@ -384,7 +391,7 @@ function editingAddRow(focus) {
 */
 function editingRemoveRow(name) {
 	const field = formField(this.form, this.name.replace(/[^[]+(.+)/, name));
-	field.parentNode.removeChild(field);
+	field.remove();
 	parentTag(this, 'tr').style.display = 'none';
 	return false;
 }
@@ -456,7 +463,7 @@ function editingLengthChange() {
 */
 function editingLengthFocus() {
 	const td = this.parentNode;
-	if (/(enum|set)$/.test(selectValue(td.previousSibling.firstChild))) {
+	if (/^(enum|set)$/.test(selectValue(td.previousSibling.firstChild))) {
 		const edit = qs('#enum-edit');
 		edit.value = enumValues(this.value);
 		td.appendChild(edit);
@@ -665,6 +672,17 @@ function sqlSubmit(form, root) {
 	}
 }
 
+/** Check if PHP can handle the uploaded files
+* @param number
+* @param string
+* @param Event
+*/
+function fileChange(event, maxFileUploads, message) {
+	if (event.target.files.length > maxFileUploads) {
+		alert(message);
+	}
+}
+
 
 
 /** Handle changing trigger time or event
